# Copyright (C) 2023 Facility for Antiproton and Ion Research in Europe, Darmstadt
# SPDX-License-Identifier: GPL-3.0-only
# First commited by Pierre-Alain Loizeau

# This script will check if the Geometry repository installation script (externals) hold any modification relative to
# the "upstream" repository.
# The result is stored as an export to the variable GEO_HASH_CHANGE in the Dart.cfg file
#
# upstream is used here in the CBM workflow and CBM CI meaning
# => designating the target branch of an MR or the official master branch
# => Not your own fork in most use cases and the script is mostly meant to be auto-called
# => Be careful if calling by hand connect_upstream_repo as it updates the remote called upstream if different!!!
#    This is typically visible by a long list of "[new branch]" when this new remote if fetched!

if [[ $# -ne 2 ]]; then
  echo "Missing argument! please call this script with both the upstream URL and the upstream branch:"
  echo "./scripts/check-geo-hash-changes.sh <url> <branch>"
  echo ""
  echo "upstream is used here in the CBM workflow and CBM CI meaning"
  echo "=> designating the target branch of an MR or the official master branch"
  echo "=> Not your own fork in most use cases and the script is mostly meant to be auto-called"
  echo "=> Be careful if calling by hand connect_upstream_repo: it updates the remote called upstream if different!!!"
  echo ""
  echo "Examples: "
  echo "./scripts/check-geo-hash-changes.sh https://git.cbm.gsi.de/computing/cbmroot.git master # https without login"
  echo "./scripts/check-geo-hash-changes.sh git@git.cbm.gsi.de:computing/cbmroot.git master     # ssh with key login"
  echo "./scripts/check-geo-hash-changes.sh $CI_MERGE_REQUEST_PROJECT_URL $CI_MERGE_REQUEST_TARGET_BRANCH_NAME # MR CI"
  exit -1
fi

# Copied from connect_upstream_repo.sh to avoid replacing an existing upstream remote!
upstream_there=$(git remote -v | grep upstream)
if [ $? -eq 0 ]; then
  upstream_there=$(git remote -v | grep upstream | grep $1)
  if [ $? -ne 0 ]; then
    echo "Remote link upstream already exist and points to a different repo, stopping here!! (not changing local conf.)"
    echo "Existing: "
    git remote -v | grep upstream
    echo "Parameter: "
    echo "upstream	$1"
    exit -1
  fi
fi

scripts/connect_upstream_repo.sh $1
git fetch upstream

BASE_COMMIT=upstream/$2

GEO_HASH_CHANGE=`git diff --name-only $BASE_COMMIT | grep external/InstallGeometry.cmake | wc -l`
echo "export GEO_HASH_CHANGE=$GEO_HASH_CHANGE" >> Dart.cfg
if [[ $GEO_HASH_CHANGE -eq 0 ]]; then
  echo "No changes found to Geometry repository install script"
else
  echo "Changes found to Geometry repository install script, assuming hash was bumped or target repo/branch changed"
fi
